==> estateplat-common-1.2.3-20180411.041127-61-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJzwsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 构（建）筑物所有权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_jzwsyq")
public class BdcJzwsyq extends QllxParent implements QllxVo{
    /* @Id
     private String qlid;//权利Id
     private String bdcdyid;//不动产单元Id*/
    private String jzwsyqr;//构（建）筑物所有权人
    private Double syqmj;//使用权面积(公顷)
    private String tdhysyqr;//土地/海域使用权人
    private Double tdhysymj;//土地/海域使用面积（m2）
    private Date syksqx;//使用开始期限
    private Date syjsqx;//使用结束期限
    private String gzwlx;//构（建）筑物类型
    private String jzwghyt;//构（建）筑物规划用途
    private Double gzwmj;//构（建）筑物面积（m2）
    private Date jgsj;//竣工时间

    private String qllx;//权利类型
    /* private String proid;//项目ID*/
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记
    private String ywh;//业务号

    private Integer qszt;//权属状态

    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_jzwsyq表增加冗余字段bdcdyh、bdcdybh、zl
     */
    private String bdcdyh; //不动产单元号

    private String bdcdybh; //不动产单元编号

    private String zl; //坐落

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }


    public java.lang.String getYwh() {
        return ywh;
    }

    public void setYwh(java.lang.String ywh) {
        this.ywh = ywh;
    }


    public java.lang.Integer getQszt() {
        return qszt;
    }

    public void setQszt(java.lang.Integer qszt) {
        this.qszt = qszt;
    }

    public String getJzwsyqr() {
        return jzwsyqr;
    }

    public void setJzwsyqr(String jzwsyqr) {
        this.jzwsyqr = jzwsyqr;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public String getTdhysyqr() {
        return tdhysyqr;
    }

    public void setTdhysyqr(String tdhysyqr) {
        this.tdhysyqr = tdhysyqr;
    }

    public Double getTdhysymj() {
        return tdhysymj;
    }

    public void setTdhysymj(Double tdhysymj) {
        this.tdhysymj = tdhysymj;
    }

    public Date getSyksqx() {
        return syksqx;
    }

    public void setSyksqx(Date syksqx) {
        this.syksqx = syksqx;
    }

    public Date getSyjsqx() {
        return syjsqx;
    }

    public void setSyjsqx(Date syjsqx) {
        this.syjsqx = syjsqx;
    }

    public String getGzwlx() {
        return gzwlx;
    }

    public void setGzwlx(String gzwlx) {
        this.gzwlx = gzwlx;
    }

    public String getJzwghyt() {
        return jzwghyt;
    }

    public void setJzwghyt(String jzwghyt) {
        this.jzwghyt = jzwghyt;
    }

    public Double getGzwmj() {
        return gzwmj;
    }

    public void setGzwmj(Double gzwmj) {
        this.gzwmj = gzwmj;
    }

    public Date getJgsj() {
        return jgsj;
    }

    public void setJgsj(Date jgsj) {
        this.jgsj = jgsj;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

}

==> estateplat-common-1.2.3-20180822.101358-168-sources.jar: cn/gtmap/estateplat/model/server/core/BdcJzwsyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 构（建）筑物所有权登记信息
 * Created by lst on 2015/3/18
 */
@Table(name = "bdc_jzwsyq")
public class BdcJzwsyq extends QllxParent implements QllxVo{
    /* @Id
     private String qlid;//权利Id
     private String bdcdyid;//不动产单元Id*/
    private String jzwsyqr;//构（建）筑物所有权人
    private Double syqmj;//使用权面积(公顷)
    private String tdhysyqr;//土地/海域使用权人
    private Double tdhysymj;//土地/海域使用面积（m2）
    private Date syksqx;//使用开始期限
    private Date syjsqx;//使用结束期限
    private String gzwlx;//构（建）筑物类型
    private String jzwghyt;//构（建）筑物规划用途
    private Double gzwmj;//构（建）筑物面积（m2）
    private Date jgsj;//竣工时间

    private String qllx;//权利类型
    /* private String proid;//项目ID*/
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记
    private String ywh;//业务号

    private Integer qszt;//权属状态

    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登薄时间

    /**
     * @author <a href="mailto:liujie@gtmap.cn">liujie</a>
     * @description bdc_jzwsyq表增加冗余字段bdcdyh、bdcdybh、zl
     */
    private String bdcdyh; //不动产单元号

    private String bdcdybh; //不动产单元编号
    private String qlqtzk; //权利其他状况
    private String zl; //坐落

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getBdcdybh() {
        return bdcdybh;
    }

    public void setBdcdybh(String bdcdybh) {
        this.bdcdybh = bdcdybh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }


    public java.lang.String getYwh() {
        return ywh;
    }

    public void setYwh(java.lang.String ywh) {
        this.ywh = ywh;
    }


    public java.lang.Integer getQszt() {
        return qszt;
    }

    public void setQszt(java.lang.Integer qszt) {
        this.qszt = qszt;
    }

    public String getJzwsyqr() {
        return jzwsyqr;
    }

    public void setJzwsyqr(String jzwsyqr) {
        this.jzwsyqr = jzwsyqr;
    }

    public Double getSyqmj() {
        return syqmj;
    }

    public void setSyqmj(Double syqmj) {
        this.syqmj = syqmj;
    }

    public String getTdhysyqr() {
        return tdhysyqr;
    }

    public void setTdhysyqr(String tdhysyqr) {
        this.tdhysyqr = tdhysyqr;
    }

    public Double getTdhysymj() {
        return tdhysymj;
    }

    public void setTdhysymj(Double tdhysymj) {
        this.tdhysymj = tdhysymj;
    }

    public Date getSyksqx() {
        return syksqx;
    }

    public void setSyksqx(Date syksqx) {
        this.syksqx = syksqx;
    }

    public Date getSyjsqx() {
        return syjsqx;
    }

    public void setSyjsqx(Date syjsqx) {
        this.syjsqx = syjsqx;
    }

    public String getGzwlx() {
        return gzwlx;
    }

    public void setGzwlx(String gzwlx) {
        this.gzwlx = gzwlx;
    }

    public String getJzwghyt() {
        return jzwghyt;
    }

    public void setJzwghyt(String jzwghyt) {
        this.jzwghyt = jzwghyt;
    }

    public Double getGzwmj() {
        return gzwmj;
    }

    public void setGzwmj(Double gzwmj) {
        this.gzwmj = gzwmj;
    }

    public Date getJgsj() {
        return jgsj;
    }

    public void setJgsj(Date jgsj) {
        this.jgsj = jgsj;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQlqtzk() {
        return qlqtzk;
    }

    public void setQlqtzk(String qlqtzk) {
        this.qlqtzk = qlqtzk;
    }
}
